@@ -19,17 +19,19 @@
 
 #include "config.h"
 
-#include <config.h>
 #include "dvi-document.h"
 #include "ev-document-thumbnails.h"
 #include "ev-document-misc.h"
 #include "ev-file-exporter.h"
+#include "ev-file-helpers.h"
 
 #include "mdvi.h"
 #include "fonts.h"
+#include "color.h"
 #include "cairo-device.h"
 
 #include <glib/gi18n.h>
+#include <ctype.h>
 
 GMutex *dvi_context_mutex = NULL;
 
@@ -67,18 +69,14 @@ typedef struct _DviDocumentClass DviDocumentClass;
 static void dvi_document_document_iface_init            (EvDocumentIface           *iface);
 static void dvi_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
 static void dvi_document_file_exporter_iface_init	(EvFileExporterIface 	   *iface);
-static void dvi_document_get_page_size 			(EvDocument                *document,
-					    		 int                        page,
-							 double                    *width,
-							 double                    *height);
 static void dvi_document_do_color_special               (DviContext                *dvi,
 							 const char                *prefix,
 							 const char                *arg);
 
 EV_BACKEND_REGISTER_WITH_CODE (DviDocument, dvi_document,
      {
-      G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS, dvi_document_document_thumbnails_iface_init);
-      G_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER, dvi_document_file_exporter_iface_init);
+      EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS, dvi_document_document_thumbnails_iface_init);
+      EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER, dvi_document_file_exporter_iface_init);
      });
 
 static gboolean
@@ -102,9 +100,10 @@ dvi_document_load (EvDocument  *document,
 	g_mutex_lock (dvi_context_mutex);
 	if (dvi_document->context)
 		mdvi_destroy_context (dvi_document->context);
-	
+
 	dvi_document->context = mdvi_init_context(dvi_document->params, dvi_document->spec, filename);
 	g_mutex_unlock (dvi_context_mutex);
+	g_free (filename);
 	
 	if (!dvi_document->context) {
     		g_set_error (error,
@@ -150,7 +149,7 @@ dvi_document_get_n_pages (EvDocument *document)
 
 static void
 dvi_document_get_page_size (EvDocument *document,
-			    int         page,
+			    EvPage     *page,
 			    double     *width,
 			    double     *height)
 {
@@ -177,7 +176,7 @@ dvi_document_render (EvDocument      *document,
 	 */
 	g_mutex_lock (dvi_context_mutex);
 	
-	mdvi_setpage (dvi_document->context, rc->page);
+	mdvi_setpage (dvi_document->context, rc->page->index);
 	
 	mdvi_set_shrink (dvi_document->context, 
 			 (int)((dvi_document->params->hshrink - 1) / rc->scale) + 1,
@@ -274,8 +273,8 @@ dvi_document_document_iface_init (EvDocumentIface *iface)
 static void
 dvi_document_thumbnails_get_dimensions (EvDocumentThumbnails *document,
 					EvRenderContext      *rc, 
-					gint                  *width,
-					gint                  *height)
+					gint                 *width,
+					gint                 *height)
 {	
 	DviDocument *dvi_document = DVI_DOCUMENT (document);
 	gdouble page_width = dvi_document->base_width;
@@ -307,7 +306,7 @@ dvi_document_thumbnails_get_thumbnail (EvDocumentThumbnails *document,
 
 	g_mutex_lock (dvi_context_mutex);
 	
-	mdvi_setpage (dvi_document->context, rc->page);
+	mdvi_setpage (dvi_document->context, rc->page->index);
 
 	mdvi_set_shrink (dvi_document->context, 
 			  (int)dvi_document->base_width * dvi_document->params->hshrink / thumb_width,
@@ -377,7 +376,7 @@ dvi_document_file_exporter_do_page (EvFileExporter  *exporter,
 {
        DviDocument *dvi_document = DVI_DOCUMENT(exporter);
 
-       g_string_append_printf (dvi_document->exporter_opts, "%d,", (rc->page) + 1);
+       g_string_append_printf (dvi_document->exporter_opts, "%d,", (rc->page->index) + 1);
 }
 
 static void
