@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-file-helpers.c 2356 2007-02-27 14:56:44Z carlosgc $
+ *  $Id: ev-file-helpers.c 3130 2008-08-31 15:20:43Z carlosgc $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,11 +29,10 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <errno.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-xfer.h>
+
+#if WITH_GNOME
 #include <libgnome/gnome-init.h>
+#endif
 
 #include "ev-file-helpers.h"
 
@@ -47,7 +46,7 @@ ensure_dir_exists (const char *dir)
 	if (g_file_test (dir, G_FILE_TEST_IS_DIR))
 		return TRUE;
 	
-	if (g_mkdir (dir, 488) == 0)
+	if (g_mkdir_with_parents (dir, 488) == 0)
 		return TRUE;
 
 	if (errno == EEXIST)
@@ -63,7 +62,8 @@ ev_dot_dir (void)
 	if (dot_dir == NULL) {
 		gboolean exists;
 
-		dot_dir = g_build_filename (gnome_user_dir_get (),
+		dot_dir = g_build_filename (g_get_home_dir (),
+					    ".gnome2",
 					    "evince",
 					    NULL);
 
@@ -113,6 +113,20 @@ ev_file_helpers_shutdown (void)
 	tmp_dir = NULL;
 }
 
+GFile *
+ev_tmp_file_get (const gchar *prefix)
+{
+	gchar *path;
+	GFile *file;
+
+	path = ev_tmp_filename (prefix);
+	file = g_file_new_for_path (path);
+	
+	g_free (path);
+	
+	return file;
+}
+
 gchar * 
 ev_tmp_filename (const gchar *prefix)
 {
@@ -136,36 +150,85 @@ ev_tmp_filename (const gchar *prefix)
 	return filename;
 }
 
+/* Remove a local temp file created by evince */
+void
+ev_tmp_filename_unlink (const gchar *filename)
+{
+	const gchar *tempdir;
+	
+	if (!filename)
+		return;
+
+	tempdir = g_get_tmp_dir ();
+	if (g_ascii_strncasecmp (filename, tempdir, strlen (tempdir)) == 0) {
+		g_unlink (filename);
+	}
+}
+
+void
+ev_tmp_file_unlink (GFile *file)
+{
+	gboolean res;
+
+	if (!file)
+		return;
+	
+	res = g_file_delete (file, NULL, NULL);
+	if (!res) {
+		char *uri;
+		
+		uri = g_file_get_uri (file);
+		g_warning ("Unable to delete temp file %s\n", uri);
+		g_free (uri);
+	}
+}
+
+void
+ev_tmp_uri_unlink (const gchar *uri)
+{
+	GFile *file;
+	
+	if (!uri)
+		return;
+	
+	file = g_file_new_for_uri (uri);
+	if (!g_file_is_native (file)) {
+		g_warning ("Attempting to delete non native uri: %s\n", uri);
+		g_object_unref (file);
+		return;
+	}
+	
+	ev_tmp_file_unlink (file);
+	g_object_unref (file);
+}
+
 gboolean
 ev_xfer_uri_simple (const char *from,
 		    const char *to,
 		    GError     **error)
 {
-	GnomeVFSResult result;
-	GnomeVFSURI *source_uri;
-	GnomeVFSURI *target_uri;
+	GFile *source_file;
+	GFile *target_file;
+	GError *ioerror;
+	gboolean result;
 	
 	if (!from)
 		return FALSE;
 	
-	source_uri = gnome_vfs_uri_new (from);
-	target_uri = gnome_vfs_uri_new (to);
+	source_file = g_file_new_for_uri (from);
+	target_file = g_file_new_for_uri (to);
+	
+	result = g_file_copy (source_file, target_file,
+			      G_FILE_COPY_OVERWRITE,
+			      NULL, NULL, NULL, &ioerror);
 
-	result = gnome_vfs_xfer_uri (source_uri, target_uri, 
-				     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
-				     GNOME_VFS_XFER_ERROR_MODE_ABORT,
-				     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-				     NULL,
-				     NULL);
-	gnome_vfs_uri_unref (target_uri);
-	gnome_vfs_uri_unref (source_uri);
+	g_object_unref (target_file);
+	g_object_unref (source_file);
     
-	if (result != GNOME_VFS_OK)
-		g_set_error (error,
-			     G_FILE_ERROR,
-			     G_FILE_ERROR_FAILED,
-			     gnome_vfs_result_to_string (result));
-	return (result == GNOME_VFS_OK);
+	if (!result) {
+		g_propagate_error (error, ioerror);
+	}
+	return result;
 
 }
 
